@@ -51,7 +51,8 @@
      FORMATNODELIST1 = 267,
      DIGIT = 268,
      LABEL = 269,
-     EOFF = 270
+     EOFF = 270,
+     ERROR = 271
    };
 #endif
 /* Tokens.  */
@@ -68,19 +69,20 @@
 #define DIGIT 268
 #define LABEL 269
 #define EOFF 270
+#define ERROR 271
 
 
 
 
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 91 "src/foreign-dl-parser.y"
+#line 86 "src/foreign-dl-parser.y"
 {
   long int integer;
   igraph_real_t real;
 }
 /* Line 1529 of yacc.c.  */
-#line 84 "y.tab.h"
+#line 86 "y.tab.h"
 	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
