@@ -1,3 +1,23 @@
+/*
+ *
+ * gengraph - generation of random simple connected graphs with prescribed
+ *            degree sequence
+ *
+ * Copyright (C) 2006  Fabien Viger
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
 #ifndef _VERTEX_COVER_H
 #define _VERTEX_COVER_H
 
@@ -9,6 +29,10 @@
 
 #include "gengraph_box_list.h"
 
+#ifndef register
+#define register
+#endif
+
 namespace gengraph { 
 
 void vertex_cover(int n, int *links, int *deg, int **neigh = NULL) {
