@@ -36,7 +36,7 @@
  * Force inclusion of SVID stuff since we need it if we're compiling in
  * gcc-wall wall mode
  */
-#define _SVID_SOURCE
+#define _DEFAULT_SOURCE
 
 #include "config.h"
 
@@ -332,10 +332,6 @@ static int flock(int fd, int op)
 }
 #endif
 
-#if !defined(HAVE_FLOCK) && !defined(__sun)
-# define HAVE_FLOCK 1
-#endif
-
 /* Assume that the gettimeofday() has microsecond granularity */
 #define MAX_ADJUSTMENT 10
 
@@ -376,17 +372,6 @@ static int get_clock(uint32_t *clock_high, uint32_t *clock_low,
 	}
 	if (state_fd >= 0) {
 		rewind(state_f);
-#ifdef HAVE_FLOCK
-		while (flock(state_fd, LOCK_EX) < 0) {
-			if ((errno == EAGAIN) || (errno == EINTR))
-				continue;
-			fclose(state_f);
-			close(state_fd);
-			state_fd = -1;
-			ret = -1;
-			break;
-		}
-#endif
 	}
 	if (state_fd >= 0) {
 		unsigned int cl;
@@ -450,9 +435,6 @@ try_again:
 			fflush(state_f);
 		}
 		rewind(state_f);
-#ifdef HAVE_FLOCK
-		flock(state_fd, LOCK_UN);
-#endif
 	}
 
 	*clock_high = clock_reg >> 32;
